<?php

/**
 * Database support: vehicle db
 *
 * @since      1.0.0
 * @package    TyresAddict
 * @subpackage TyresAddict/Finder/includes
 * @author     TyresAddict
 * @link       http://b2b.tyresaddict.com
 */

namespace TyresAddict\Finder;

// DB class

class DB 
{
	const _vehicle_db = 'tyresaddict_woo_finder_vehicledb';

	public static function vehicle_db()
	{
		global $wpdb;
		return $wpdb->prefix . self::_vehicle_db;
	}

	public static function vehicle_records_count() 
	{
		global $wpdb;

		$sql = "SELECT COUNT(*) as cnt FROM " . DB::vehicle_db() . "";
		$result = $wpdb->get_results( $sql );

		return $result[0]->cnt;
	}

	public static function makes() 
	{
		global $wpdb;

		$sql = "SELECT vendor as make_name FROM " . DB::vehicle_db() . " GROUP BY vendor";
		$result = $wpdb->get_results( $sql );

		$makes = [];
		foreach($result as $make) {
			$makes[] = $make->make_name;
		}

		return $makes;
	}

	public static function models( $vendor )
	{
		global $wpdb;

		$sql = "SELECT car as model_name FROM " . DB::vehicle_db() . "
				WHERE vendor = %s
				GROUP BY car";

		$result = $wpdb->get_results( $wpdb->prepare( $sql, $vendor ) );

		$models = [];
		foreach($result as $model) {
			$models[] = $model->model_name;
		}

		return $models;
	}

	public static function years( $vendor, $model )
	{
		global $wpdb;

		$sql = "SELECT year FROM " . DB::vehicle_db() . "
				WHERE vendor = %s AND car = %s
				GROUP BY year";

		$result = $wpdb->get_results( $wpdb->prepare( $sql, [ $vendor, $model ] ) );

		$years = [];
		foreach($result as $year) {
			$years[] = $year->year;
		}

		return $years;
	}

	public static function mods( $vendor, $model, $year )
	{
		global $wpdb;

		$sql = "SELECT modification FROM " . DB::vehicle_db() . "
				WHERE vendor = %s AND car = %s AND year = %d
				GROUP BY modification";

		$result = $wpdb->get_results( $wpdb->prepare( $sql, [ $vendor, $model, $year ] ) );

		$mods = [];
		foreach($result as $mod) {
			$mods[] = $mod->modification;
		}

		return $mods;
	}

	public static function parse_size( $str, $filter_url, $trim )
	{
		if (preg_match('/(\d+)\/(\d+)\s*r([,\.\d]+)/i', $str, $matches))
		{
			$size = [ 'w' => $matches[1], 'p' => $matches[2], 'r' => str_replace(',','.', $matches[3]) ];

			$params = [
							'filter-car=' . urlencode( $trim->car_full ),
							'fmake=' . urlencode( $trim->vendor ),
							'fmodel=' . urlencode( $trim->car ),
							'fyear=' . urlencode( $trim->year ),
							'fmod=' . urlencode( $trim->modification ),
							PluginOptions::value('t_field_width') 	. '=' . $size['w'],
							PluginOptions::value('t_field_profile') . '=' . $size['p'],
							PluginOptions::value('t_field_r') 		. '=' . $size['r'],
						];

			$url = parse_url( $filter_url) ;
			
			if ( isset( $url['query'] ) )
				$params = array_merge( [ $url['query'] ], $params );

			$size['filter_url'] = $url['path']. '?' . implode( '&', $params );
			
			return $size;
		}

		return [];
	}
	
	public static function parse_wheel_size( $str, $filter_url, $trim )
	{                                  
		if (preg_match('/([,\.\d]+)\s*x\s*(\d+)\s*et([,\.\d]+)/i', $str, $matches))
		{
			$size = [ 'w' => str_replace(',','.', $matches[1]), 'r' => str_replace(',','.', $matches[2]), 'et' => str_replace(',','.', $matches[3]) ];

			$params = [
							'filter-car=' . urlencode( $trim->car_full ),
							'fmake=' . urlencode( $trim->vendor ),
							'fmodel=' . urlencode( $trim->car ),
							'fyear=' . urlencode( $trim->year ),
							'fmod=' . urlencode( $trim->modification ),
							PluginOptions::value('w_field_width') 	. '=' . $size['w'],
							PluginOptions::value('w_field_r') 		. '=' . $size['r'],
							PluginOptions::value('w_field_pcd') 	. '=' . $trim->param_pcd,
							PluginOptions::value('w_field_dia') 	. '=' . $trim->param_dia,
							PluginOptions::value('w_field_et') 		. '=' . $size['et'],
						];

			$url = parse_url( $filter_url) ;
			
			if ( isset( $url['query'] ) )
				$params = array_merge( [ $url['query'] ], $params );

			$size['filter_url'] = $url['path']. '?' . implode( '&', $params );
			
			return $size;
		}

		return [];
	}

	public static function parse_size_bundle( $str, $filter_url, $trim )
	{
		$bundle_sizes = [];

		if ( trim( $str ) == '' )
			return [];

		foreach( explode("|", $str) as $size_line )
		{
			$bundle_line = [ 'type' => 'both', 'size' => [] ];

			$line_sizes_fb = explode(",", $size_line);
			                          
			if ( count( $line_sizes_fb ) == 1 )
				$bundle_line['size'] = [ 'both' => DB::parse_size( $line_sizes_fb[0], $filter_url, $trim ), []];
			else
			{
				$bundle_line['type'] = 'separate';
				$bundle_line['size'] = [ 	'front' => DB::parse_size( $line_sizes_fb[0], $filter_url, $trim ), 
											'rear' => DB::parse_size( $line_sizes_fb[1], $filter_url, $trim ) ];
			}

			$bundle_sizes[] = $bundle_line;
		}

		return $bundle_sizes;
	}

	public static function parse_wheel_size_bundle( $str, $filter_url, $trim )
	{
		$bundle_sizes = [];

		if ( trim( $str ) == '' )
			return [];

		foreach( explode("|", $str) as $size_line )
		{
			$bundle_line = [ 'type' => 'both', 'size' => [] ];

			$line_sizes_fb = explode(",", $size_line);
			                          
			if ( count( $line_sizes_fb ) == 1 )
				$bundle_line['size'] = [ 'both' => DB::parse_wheel_size( $line_sizes_fb[0], $filter_url, $trim ), []];
			else
			{
				$bundle_line['type'] = 'separate';
				$bundle_line['size'] = [ 	'front' => DB::parse_wheel_size( $line_sizes_fb[0], $filter_url, $trim ), 
											'rear' 	=> DB::parse_wheel_size( $line_sizes_fb[1], $filter_url, $trim ) ];
			}

			$bundle_sizes[] = $bundle_line;
		}

		return $bundle_sizes;
	}

	public static function trim( $vendor, $model, $year, $mod, $filter_url )
	{
		global $wpdb;

		$sql = "SELECT * FROM " . DB::vehicle_db() . "
				WHERE vendor = %s AND car = %s AND year = %d AND modification = %s";

		$result = $wpdb->get_results( $wpdb->prepare( $sql, [ $vendor, $model, $year, $mod ] ) );

		if (isset($result[0]))
		{
			$result[0]->car_full = $vendor . ' ' . $model . ' ' . $year . ' ' . $mod;
	
			$result[0]->tyres_factory 	= DB::parse_size_bundle( $result[0]->tyres_factory, $filter_url, $result[0] );
			$result[0]->tyres_replace 	= DB::parse_size_bundle( $result[0]->tyres_replace, $filter_url, $result[0] );
			$result[0]->tyres_tuning 	= DB::parse_size_bundle( $result[0]->tyres_tuning, $filter_url, $result[0] );

			$result[0]->param_pcd 		= str_replace('*','x', $result[0]->param_pcd);

			$result[0]->wheels_factory 	= DB::parse_wheel_size_bundle( $result[0]->wheels_factory, $filter_url, $result[0] );
			$result[0]->wheels_replace 	= DB::parse_wheel_size_bundle( $result[0]->wheels_replace, $filter_url, $result[0] );
			$result[0]->wheels_tuning 	= DB::parse_wheel_size_bundle( $result[0]->wheels_tuning, $filter_url, $result[0] );
		}

		return $result[0];
	}


	public static function insert( $record )
	{
		global $wpdb;

		$sql = "INSERT INTO " . DB::vehicle_db() . "
					( `vendor`, `model_seria`, `car`, `modification`, `year`,
						`tyres_factory`, `tyres_replace`, `tyres_tuning`,
						`wheels_factory`, `wheels_replace`, `wheels_tuning`,
						`param_pcd`, `param_dia`, `param_nut`, `param_bolt`
						 )
				VALUES ( %s, %s, %s, %s, %s, 
						%s, %s, %s,
						%s, %s, %s,
						%s, %s, %s, %s
					)";

		$wpdb->query( $wpdb->prepare( $sql, [ 			
			$record['vendor'],
			$record['model_seria'],
			$record['car'], 
			$record['modification'],
			$record['year'],

			$record['tyres_factory'],
			$record['tyres_replace'],
			$record['tyres_tuning'],

			$record['wheels_factory'],
			$record['wheels_replace'],
			$record['wheels_tuning'],

			$record['param_pcd'],
			$record['param_dia'],
			$record['param_nut'],
			$record['param_bolt'],
		] ) );
	}
	
	public static function insert_bulk( $records )
	{
		global $wpdb;

		$sql = "INSERT INTO " . DB::vehicle_db() . "
					( `vendor`, `model_seria`, `car`, `modification`, `year`,
						`tyres_factory`, `tyres_replace`, `tyres_tuning`,
						`wheels_factory`, `wheels_replace`, `wheels_tuning`,
						`param_pcd`, `param_dia`, `param_nut`, `param_bolt`
						 )
				VALUES "; 

		$values = [];				
		foreach( $records as $record )
		{       
			$values[] = "( '" . esc_sql( $record['vendor'] ) . "', '" . 
								esc_sql( $record['model_seria'] ) . "', '" . 
								esc_sql( $record['car'] ) . "', '" . 
								esc_sql( $record['modification'] ) . "', '" . 
								esc_sql( $record['year'] ) . "', '" . 

								esc_sql( $record['tyres_factory'] ) . "', '" . 
								esc_sql( $record['tyres_replace'] ) . "', '" . 
								esc_sql( $record['tyres_tuning'] ) . "', '" . 

								esc_sql( $record['wheels_factory'] ) . "', '" . 
								esc_sql( $record['wheels_replace'] ) . "', '" . 
								esc_sql( $record['wheels_tuning'] ) . "', '" . 

								esc_sql( $record['param_pcd'] ) . "', '" . 
								esc_sql( $record['param_dia'] ) . "', '" . 
								esc_sql( $record['param_nut'] ) . "', '" . 
								esc_sql( $record['param_bolt'] ) . "' )\n"; 
		}

		$sql = $sql . implode(",", $values);

	    $wpdb->query( $sql );
	}

	public static function truncate()
	{
	    global $wpdb;

		$sql = "TRUNCATE TABLE " . DB::vehicle_db();
		$wpdb->query( $sql );
	}

	public static function tyre_width()
	{
		return [135,145,155,165,175,185,195,
				205,215,225,235,245,255,265,275,285,295,
				305,315,325,335,345,355,365];
	}

	public static function tyre_profile()
	{
		return [25,30,35,40,45,50,55,60,65,70,75,80,85,100];
	}

	public static function tyre_r()
	{
		return [12,13,14,15,16,17,18,19,20,21,22,23,24];
	}

	// wheel size 

	public static function wheel_width()
	{
		return [ 3.5,4, 4.5, 5, 5.5, 6, 6.5, 7, 7.5, 8,
				8.5, 9, 9.5, 10, 10.5, 11, 11.5 ];
	}

	public static function wheel_r()
	{
		return [12,13,14,15,16,17,18,19,20,21,22,23,24];
	}

	public static function wheel_pcd()
	{
		return [ 	
			'3x98', '3x112',
			'4x100', '4x108', '4x114', '4x114.3', '4x98',
			'5x100', '5x105', '5x108', '5x110', '5x112', '5x114', '5x114.3', '5x115', '5x118',
			'5x120', '5x120.6', '5x127', '5x128','5x130', '5x135', '5x139.7',
			'5x150', '5x160', '5x165', '5x98',
			'6x114.3', '6x115', '6x120', '6x125', '6x127', '6x130', '6x132', '6x135', '6x139.7', '6x180',
			'8x165.1','8x170','8x180'
		];
	}

	public static function wheel_dia()
	{
		return [ 	
					48.1, 
					54, 54.1, 56, 56.1, 56.5, 56.6, 57.1, 58, 58.1, 58.5, 58.6, 59.1, 59.6, 
					60, 60.1, 63.1, 63.3, 63.4, 63.5, 64.1, 65, 65.1, 65.2, 66, 66.1, 66.5, 66.6, 66.7, 66.9, 67, 67.1, 68.1, 69.1, 69.5, 
					70.1, 70.2, 70.3, 70.4, 70.5, 70.6, 71.1, 71.4, 71.5, 71.6, 72.5, 72.6, 73.1, 73.8, 74.1, 75.1, 76, 77.7, 77.8, 78, 78.1, 78.3, 
					84, 84.1, 86, 86.5, 86.8, 87, 87.1, 89, 
					92.5, 93, 93.1, 95.3, 98.5, 
					100, 100.1, 100.3, 102.6, 105, 106, 106.1, 106.2, 107.1, 108, 108.1, 108.4, 108.5, 
					110, 110.1, 111, 113, 114.5, 116.1, 116.6, 117, 
					120.9, 124.1, 124.9, 125, 
					138.8
		];
	}

	static public function wheel_et()
	{
		return [ 	'-1'	=> __('Less than 0', Plugin::lang), 
					'0'		=> '0-10',
					'10'	=> '10-20',
					'20'	=> '20-30',
					'30'	=> '30-40',
					'40'	=> '40-50',
					'50'	=> __('More than 50', Plugin::lang), 
		];
	}
}                                  





