<?php

/**
 * Tyre Finder widget functionality
 * 
 * @since      1.0.0
 * @package    TyresAddict
 * @subpackage TyresAddict/Finder/includes
 * @author     TyresAddict
 * @link       http://b2b.tyresaddict.com
 */

namespace TyresAddict\Finder;



// FinderWidget

class FinderTyreWidget extends \WP_Widget 
{
	const shortcode = 'tyresaddict-tyre-finder';

	private $default_options = [ 	'theme' => '',
									'tyre_vehicle_tab' 	=> null,
									'tyre_size_tab' 	=> null,
									 ];


	// Register widget with WordPress.

	function __construct() 
	{
		parent::__construct(
			'tyresaddict_woo_tyre_finder_widget', // ID
			__( 'TyresAddict Tyre Finder Widget', Plugin::name ),
			[ 
				'description' => __( 'TyresAddict Tyre Finder for WooCommerce. Tyres by Size and Vehicle (Make, Model, Year, Engine)', Plugin::name ), 
			]
		);

		add_shortcode( self::shortcode, [ $this, 'tyre_finder_shortcode' ] );

		add_action( 'widgets_init', function(){    
			register_widget( 'TyresAddict\Finder\FinderTyreWidget' ); 
		} );
	}

	
	public function tyre_finder_shortcode( $atts, $content = null ) 
	{
	    $atts = array_change_key_case( (array) $atts, CASE_LOWER );		// normalize attribute keys, lowercase
	    $atts = shortcode_atts( $this->default_options, $atts );		// override default attributes with user attributes
	                                                              
		return $this->render( $atts['theme'], $atts['tyre_vehicle_tab'], $atts['tyre_size_tab'] );
    }

	public function render( $theme = '', $tyre_vehicle_tab = null, $tyre_size_tab = null )
	{
		ob_start();
			$this->template( $theme, $tyre_vehicle_tab, $tyre_size_tab );
		return ob_get_clean();
	}
	

	function template( $theme = '', $tyre_vehicle_tab = null, $tyre_size_tab = null )
	{
		$params['widget'] 	= 'tyre';

		// tabs

		$params['tab_tyre_vehicle'] 	= PluginOptions::value('tab_tyre_vehicle');
		$params['tab_tyre_size'] 		= PluginOptions::value('tab_tyre_size');

		// rewrite by widget atts

		if ( $tyre_vehicle_tab !== null )	$params['tab_tyre_vehicle'] = $tyre_vehicle_tab;
		if ( $tyre_size_tab !== null )   	$params['tab_tyre_size'] 	= $tyre_size_tab;

		// data for tabs

		if ( $params['tab_tyre_vehicle'] )
		{
			$params['makes'] = DB::makes();
		}
		
		if ( $params['tab_tyre_size'] )
		{
			$params['tyre_width'] 	= Db::tyre_width();
			$params['tyre_profile'] = Db::tyre_profile();
			$params['tyre_r'] 		= Db::tyre_r();
		}

		// tyre form urls

		$params['tyre_url']	= PluginOptions::value('tyre_url');

		if ( $params['tyre_url'] == '' )
			$params['tyre_url'] = Woo::shop_url();

		// field names

		$params['t_fields']['width'] 	= PluginOptions::value('t_field_width');
		$params['t_fields']['profile'] 	= PluginOptions::value('t_field_profile');
		$params['t_fields']['r']		= PluginOptions::value('t_field_r');

		$params['show_r'] 				= PluginOptions::value('show_r');

		$theme = ( $theme == '' ) ? PluginOptions::value('theme') : $theme;

		if ( $theme == 'all' )
			$theme = 'white';

		$template = new Template();
		
		$template->display('finder', $theme, $params);
		$template->display('finder-popup', '', $params);
	}	
	
	// Front-end display of widget.

	public function widget( $args, $instance ) 
	{
		echo $args['before_widget'];

		// title
		if ( !empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}

		$theme = isset( $instance['theme'] ) ? $instance['theme'] : '';

		echo $this->render( $theme, $instance['tyre_vehicle_tab'], $instance['tyre_size_tab'] );

		echo $args['after_widget'];
	}

	// widget settings.

	public function form( $instance ) 
	{
		$title = isset( $instance['title'] ) ? $instance['title'] : '';
		$theme = isset( $instance[ 'theme' ] ) ? $instance[ 'theme' ] : '';
		?>
		<p>
			<label for="<?=esc_attr( $this->get_field_id( 'title' ) ); ?>"><?=esc_attr_e( 'Title:', Plugin::name ); ?></label> 
			<input class="widefat" id="<?=esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?=esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?=esc_attr( $title ); ?>">
		</p>
		<p>
        	<label><input type="checkbox" id="tyre_vehicle_tab" size="80" name="<?=esc_attr( $this->get_field_name( 'tyre_vehicle_tab' ) ); ?>"
		 	<?php echo ( ( isset( $this->options[ 'tyre_vehicle_tab' ] ) && !$this->options[ 'tyre_vehicle_tab' ] ) ? '' : 'checked' ); ?>
			/>
			<?=__('Show Tyres by Vehicle tab', Plugin::name ) ?>
			</label>

			<br>
        	
        	<label><input type="checkbox" id="tyre_size_tab" size="80" name="<?=esc_attr( $this->get_field_name( 'tyre_size_tab' ) ); ?>"
		 	<?php echo ( ( isset( $this->options[ 'tyre_size_tab' ] ) && !$this->options[ 'tyre_size_tab' ] ) ? '' : 'checked' ); ?>
			/>
			<?=__('Show Tyres by Size tab', Plugin::name ) ?>
			</label>
		</p>
		<?php 
	}
/*
		<p>
			<label for="<?=esc_attr( $this->get_field_id( 'theme' ) ); ?>"><?=esc_attr_e( 'Theme:', Plugin::name ) ?></label> 
        	<select id="<?=esc_attr( $this->get_field_id( 'theme' ) ); ?>" 
        			name="<?=esc_attr( $this->get_field_name( 'theme' ) ); ?>">
				<option <?=( ( $theme == '' ) ? 'selected' : '' ) ?> value=""><?=__('Use global settings') ?></option>

				<?php foreach( PluginOptions::themes as $theme_id => $theme_name ): ?>
				<option <?=( ( $theme == $theme_id ) ? 'selected' : '' ) ?> value="<?=$theme_id ?>"><?=$theme_name ?></option>
				<?php endforeach ?>
			</select>
		</p>
*/
	// sanitize widget settings

	public function update( $new_instance, $old_instance ) 
	{
		$instance = $old_instance;
		$instance['title'] = isset( $new_instance['title'] ) ? wp_strip_all_tags( $new_instance['title'] ) : '';

		$instance['tyre_vehicle_tab'] 	= isset( $new_instance['tyre_vehicle_tab'] ) ? true : false;
		$instance['tyre_size_tab'] 		= isset( $new_instance['tyre_size_tab'] ) ? true : false;
		
		//$instance['theme'] = isset( $new_instance['theme'] ) ? wp_strip_all_tags( $new_instance['theme'] ) : '';

		return $instance;
	}


}



		
