<?php

/**
 * Wheel Finder widget functionality
 * 
 * @since      1.0.0
 * @package    TyresAddict
 * @subpackage TyresAddict/Finder/includes
 * @author     TyresAddict
 * @link       http://b2b.tyresaddict.com
 */

namespace TyresAddict\Finder;



// FinderWidget

class FinderWheelWidget extends \WP_Widget 
{
	const shortcode = 'tyresaddict-wheel-finder';

	private $default_options = [ 	'theme' => '',
									'wheel_vehicle_tab' => null,
									'wheel_size_tab' 	=> null,
									 ];


	function __construct() 
	{
		parent::__construct(
			'tyresaddict_woo_wheel_finder_widget', // ID
			__( 'Tyres | Wheel Finder widget', Plugin::lang ),
			[ 
				'description' => __( 'TyresAddict Wheel Finder Pro. Wheels by size and vehicle (Make, Model, Year, Engine)', Plugin::lang ), 
			]
		);

		add_shortcode( self::shortcode, [ $this, 'wheel_finder_shortcode' ] );

		add_action( 'widgets_init', function(){    
			register_widget( 'TyresAddict\Finder\FinderWheelWidget' ); 
		} );
	}


	public function wheel_finder_shortcode( $atts, $content = null ) 
	{
	    $atts = array_change_key_case( (array) $atts, CASE_LOWER );		// normalize attribute keys, lowercase
	    $atts = shortcode_atts( $this->default_options, $atts );		// override default attributes with user attributes
	                                                              
		return $this->render( $atts['theme'], $atts['wheel_vehicle_tab'], $atts['wheel_size_tab'] );
    }


	public function render( $theme = '', $wheel_vehicle_tab = null, $wheel_size_tab = null )
	{
		ob_start();
			$this->template( $theme, $wheel_vehicle_tab, $wheel_size_tab );
		return ob_get_clean();
	}
	

	function template( $theme = '', $wheel_vehicle_tab = null, $wheel_size_tab = null )
	{
		$params['widget'] 	= 'wheel';

		// tabs

		$params['tab_wheel_vehicle'] 	= PluginOptions::value('tab_wheel_vehicle');
		$params['tab_wheel_size'] 		= PluginOptions::value('tab_wheel_size');

		// rewrite by widget atts

		if ( $wheel_vehicle_tab !== null )	$params['tab_wheel_vehicle'] 	= $wheel_vehicle_tab;
		if ( $wheel_size_tab !== null )   	$params['tab_wheel_size'] 		= $wheel_size_tab;

		// data for tabs

		if ( $params['tab_wheel_vehicle'] )
		{
			$params['makes'] = DB::makes();
		}
		
		if ( $params['tab_wheel_size'] )
		{
			$params['wheel_width'] 	= Db::wheel_width();
			$params['wheel_r'] 		= Db::wheel_r();
			$params['wheel_pcd'] 	= Db::wheel_pcd();
			$params['wheel_dia'] 	= Db::wheel_dia();
			$params['wheel_et'] 	= Db::wheel_et();
		}

		// wheel form urls

		$params['wheel_url'] 	= PluginOptions::value('wheel_url');

		if ( $params['wheel_url'] == '')
			$params['wheel_url'] = Woo::shop_url();

		// field names

		$params['w_fields']['width'] 	= PluginOptions::value('w_field_width');
		$params['w_fields']['r']		= PluginOptions::value('w_field_r');
		$params['w_fields']['pcd'] 		= PluginOptions::value('w_field_pcd');
		$params['w_fields']['dia']		= PluginOptions::value('w_field_dia');
		$params['w_fields']['et'] 		= PluginOptions::value('w_field_et');

		$params['show_r'] 				= PluginOptions::value('show_r');

		$theme = ( $theme == '' ) ? PluginOptions::value('theme') : $theme;

		if ( $theme == 'all' )
			$theme = 'white';

		$template = new Template();
		
		$template->display('finder', $theme, $params);
		$template->display('finder-popup', '', $params);
	}	
	
	// Front-end display of widget.

	public function widget( $args, $instance ) 
	{
		echo $args['before_widget'];

		// title
		if ( !empty( $instance['title'] ) ) {
			echo $args['before_title'] . apply_filters( 'widget_title', $instance['title'] ) . $args['after_title'];
		}

		$theme = isset( $instance['theme'] ) ? $instance['theme'] : '';

		echo $this->render( $theme, $instance['wheel_vehicle_tab'], $instance['wheel_size_tab'] );

		echo $args['after_widget'];
	}

	// widget settings.

	public function form( $instance ) 
	{
		$title = isset( $instance['title'] ) ? $instance['title'] : '';
		$theme = isset( $instance[ 'theme' ] ) ? $instance[ 'theme' ] : '';
		?>
		<p>
			<label for="<?=esc_attr( $this->get_field_id( 'title' ) ); ?>"><?=esc_attr_e( 'Title:', Plugin::lang ); ?></label> 
			<input class="widefat" id="<?=esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?=esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?=esc_attr( $title ); ?>">
		</p>
		<p>
        	<label><input type="checkbox" id="wheel_vehicle_tab" size="80" name="<?=esc_attr( $this->get_field_name( 'wheel_vehicle_tab' ) ); ?>"
		 	<?php echo ( ( isset( $this->options[ 'wheel_vehicle_tab' ] ) && !$this->options[ 'wheel_vehicle_tab' ] ) ? '' : 'checked' ); ?>
			/>
			<?=__('Show Wheels by Vehicle tab', Plugin::lang ) ?>
			</label>

			<br>
        	
        	<label><input type="checkbox" id="wheel_size_tab" size="80" name="<?=esc_attr( $this->get_field_name( 'wheel_size_tab' ) ); ?>"
		 	<?php echo ( ( isset( $this->options[ 'wheel_size_tab' ] ) && !$this->options[ 'wheel_size_tab' ] ) ? '' : 'checked' ); ?>
			/>
			<?=__('Show Wheels by Size tab', Plugin::lang ) ?>
			</label>
		</p>
		<?php 
	}
/*
		<p>
			<label for="<?=esc_attr( $this->get_field_id( 'theme' ) ); ?>"><?=esc_attr_e( 'Theme:', Plugin::lang ) ?></label> 
        	<select id="<?=esc_attr( $this->get_field_id( 'theme' ) ); ?>" 
        			name="<?=esc_attr( $this->get_field_name( 'theme' ) ); ?>">
				<option <?=( ( $theme == '' ) ? 'selected' : '' ) ?> value=""><?=__('Use global settings', Plugin::lang) ?></option>

				<?php foreach( PluginOptions::themes as $theme_id => $theme_name ): ?>
				<option <?=( ( $theme == $theme_id ) ? 'selected' : '' ) ?> value="<?=$theme_id ?>"><?=$theme_name ?></option>
				<?php endforeach ?>
			</select>
		</p>
*/
	// sanitize widget settings

	public function update( $new_instance, $old_instance ) 
	{
		$instance = $old_instance;
		$instance['title'] = isset( $new_instance['title'] ) ? wp_strip_all_tags( $new_instance['title'] ) : '';

		$instance['wheel_vehicle_tab'] 	= isset( $new_instance['wheel_vehicle_tab'] ) ? true : false;
		$instance['wheel_size_tab'] 	= isset( $new_instance['wheel_size_tab'] ) ? true : false;

		//$instance['theme'] = isset( $new_instance['theme'] ) ? wp_strip_all_tags( $new_instance['theme'] ) : '';

		return $instance;
	}


} // \FinderWidget



		
