<?php

/**
 * Option page of the plugin.
 *
 * @since      1.0.0
 * @package    TyresAddict
 * @subpackage TyresAddict/Finder/includes
 * @author     TyresAddict
 * @link       http://b2b.tyresaddict.com
 */

namespace TyresAddict\Finder;



class PageOptions
{
	private $options 	= [];


	public function __construct() 
	{              
		$this->register();
	}

	function page() 
	{
		if ( !current_user_can( 'manage_options' ) )  {
			wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
		}

        $this->options = get_option( PluginOptions::OptionGroup );
        ?>
        <div class="wrap">
            <h1 class="wp-heading-inline"><?=Plugin::title ?> Pro Options</h1>
            <form method="post" action="options.php" enctype="multipart/form-data">
            <?php
                settings_fields( PluginOptions::OptionGroup );
                do_settings_sections( PluginOptions::OptionPage );
                submit_button();
            ?>
            </form>
        </div>
        <?php
	}

	function handle_db_upload($option)
	{
		// tabs options
		         
		if( isset( $option['tab_tyre_vehicle'] ) && $option['tab_tyre_vehicle'] == 'on' )		$option['tab_tyre_vehicle'] = true;
		else                                                                             		$option['tab_tyre_vehicle'] = false;

		if( isset( $option['tab_tyre_size'] ) && $option['tab_tyre_size'] == 'on' )				$option['tab_tyre_size'] = true;
		else                                                                       				$option['tab_tyre_size'] = false;

		if( isset( $option['tab_wheel_vehicle'] ) && $option['tab_wheel_vehicle'] == 'on' )		$option['tab_wheel_vehicle'] = true;
		else                                                                             		$option['tab_wheel_vehicle'] = false;

		if( isset( $option['tab_wheel_size'] ) && $option['tab_wheel_size'] == 'on' )			$option['tab_wheel_size'] = true;
		else                                                             	          			$option['tab_wheel_size'] = false;

		if( isset( $option['show_r'] ) && $option['show_r'] == 'on' )			$option['show_r'] = true;
		else																	$option['show_r'] = false;

		// upload db

	    if ( $_FILES[ PluginOptions::OptionGroup ]['tmp_name']['vehicle_file'] != '' )
	    {
	    	$file_name = $_FILES[ PluginOptions::OptionGroup ]['name']['vehicle_file'];
	    	$file_info = pathinfo( $file_name );

	    	if ( $file_info['extension'] == 'zip')
	    	{
				$zip = new \ZipArchive();
 				if ( $zip->open( $_FILES[ PluginOptions::OptionGroup ]['tmp_name']['vehicle_file'] ) === true)
				{	    
					$csv_file = $zip->getFromIndex(0);
    				$zip->close();
    			}
				else
				{
					add_settings_error( PluginOptions::OptionGroup, "tawf-opt-message", __( 'Invalid ZIP file format', Plugin::lang ), 'warning');
    				return $option;
				}
	        }
	    	elseif ( $file_info['extension'] == 'csv')
	    	{
				$csv_file = file_get_contents( $_FILES[ PluginOptions::OptionGroup ]['tmp_name']['vehicle_file'] );
			}
			else
			{
				add_settings_error( PluginOptions::OptionGroup, "tawf-opt-message", __( 'Invalid Vehicle Fitment DB file format', Plugin::lang ), 'warning');
    			return $option;
			}
			
			// parse

			$csv_lines = explode("\n", $csv_file);
	
		    if ( count( $csv_lines ) == 0 )
		    {
				add_settings_error( PluginOptions::OptionGroup, "tawf-opt-message", __( 'Invalid CSV file format', Plugin::lang ), 'warning');
    			return $option;
		    }

			DB::truncate();

			$records = [];
			foreach( $csv_lines as $line )
			{
				$data = explode(';', $line);

		    	if ( count( $data ) < 8 )
		    		continue;
	
				$record['vendor'] 		= $data[0];
				$record['model_seria'] 	= $data[1];
				$record['car'] 			= $data[2];
				$record['modification'] = $data[3];
				$record['year'] 		= $data[4];

				$record['tyres_factory'] 	= $data[5];
				$record['tyres_replace'] 	= $data[6];
				$record['tyres_tuning'] 	= $data[7];

				$record['wheels_factory'] 	= $data[8];
				$record['wheels_replace'] 	= $data[9];
				$record['wheels_tuning'] 	= $data[10];

				$record['param_pcd'] 	= $data[11];
				$record['param_dia'] 	= $data[12];
				$record['param_nut'] 	= $data[13];
				$record['param_bolt'] 	= $data[14];

				$records[] = $record;

				if ( count( $records ) >= 300 )
				{
					DB::insert_bulk( $records );
					$records = [];
				}
			}

			// insert last records
			DB::insert_bulk( $records );

			add_settings_error( PluginOptions::OptionGroup, "tawf-opt-message", __( 'Settings saved. CSV file imported.', Plugin::lang ), 'updated');
		}
        
    	return $option;
	}
    
	public function register_page()
    {        
        register_setting(
            PluginOptions::OptionGroup, 	// Option group
            PluginOptions::OptionGroup, 	// Option name
            [ $this, 'handle_db_upload' ] 	// validation & upload
        );

        add_settings_section(
            'vehicle_data_section_id', 				// ID
            __( 'Vehicle Data', Plugin::lang ), 
            [ $this, 'vehicle_data_info' ], 		// Callback
            PluginOptions::OptionPage 				// Page
        );  

        add_settings_field(							// OPTION: Data File
            'vehicle_file', 						
            __( 'Vehicle Data File:', Plugin::lang ), 
            [ $this, 'vehicle_file_callback' ], 
            PluginOptions::OptionPage,
            'vehicle_data_section_id' 				// section           
        );      

        add_settings_field(							// OPTION: Show Tabs
            'show_tabs', 
            __( 'Global Tab Settings:', Plugin::lang ), 
            [ $this, 'tabs_callback' ], 
            PluginOptions::OptionPage, 
            'vehicle_data_section_id'
        );      

        add_settings_field(							// OPTION: Tyre filter URL
            'size_action', 
            __( 'Tyre Filter URL:', Plugin::lang ), 
            [ $this, 'tyre_url_callback' ], 
            PluginOptions::OptionPage, 
            'vehicle_data_section_id'
        );      

        add_settings_field(							// OPTION: Tyre fields
            'tyre_fields', 
            __( 'Tyre fields for Filter:', Plugin::lang ), 
            [ $this, 'tyre_fields_callback' ], 
            PluginOptions::OptionPage, 
            'vehicle_data_section_id'
        );      

        add_settings_field(							// OPTION: Wheel filter URL
            'wheel_url', 
            __( 'Wheel filter URL:', Plugin::lang ), 
            [ $this, 'wheel_url_callback' ], 
            PluginOptions::OptionPage, 
            'vehicle_data_section_id'
        );      

        add_settings_field(							// OPTION: Wheel fields
            'wheel_fields', 
            __( 'Wheel fields for Filter:', Plugin::lang ), 
            [ $this, 'wheel_fields_callback' ], 
            PluginOptions::OptionPage, 
            'vehicle_data_section_id'
        );      

        add_settings_field(							// OPTION: Popup settings
            'popup_type', 
            __( 'Vehicle Fitment Popup:', Plugin::lang ), 
            [ $this, 'popup_callback' ], 
            PluginOptions::OptionPage, 
            'vehicle_data_section_id'
        );      

        add_settings_field(							// OPTION: Theme
            'theme', 
            __( "UI & Theme:", Plugin::lang ), 
            [ $this, 'theme_callback' ], 
            PluginOptions::OptionPage, 
            'vehicle_data_section_id'
        );      

        add_settings_field(							// OPTION: CSS
            'custom_css', 
            __( "Rewrite CSS:", Plugin::lang ), 
            [ $this, 'custom_css_callback' ], 
            PluginOptions::OptionPage, 
            'vehicle_data_section_id'
        );      

	}
	
	public function vehicle_data_info()
    {
        print __( 'Records in DB : ', Plugin::lang ) . DB::vehicle_records_count();
    	$this->shortcodes_info();
    }

    public function shortcodes_info()
    {
    	echo '<div style="position:absolute; float:right; background: #e6e6e6; right:30px; width:20%; padding: 20px;font-size: 14px;margin-bottom: 20px;">';
    	echo '<h4 style="margin-top:0;">Shortcodes</h4>';
    	echo '<p>Tyre Finder<br>[tyresaddict-tyre-finder]</p>';
    	echo '<p>Wheel Finder<br>[tyresaddict-wheel-finder]</p>';
    	echo '</div>';
    }
    
    public function vehicle_file_callback()
    {
		echo '<input type="file" id="vehicle_file" name="' . PluginOptions::OptionGroup . '[vehicle_file]" />';
		echo '<br>';
		echo __( 'File: <i>Should have CSV format with vehicle fitment data</i>', Plugin::lang );
    }

	public function tabs_callback()
    {
		echo __('Show <b>Tyre</b> tabs: ', Plugin::lang ) . '<br>';
        echo '<label><input type="checkbox" id="tab_tyre_vehicle" size="80" name="' . PluginOptions::OptionGroup . '[tab_tyre_vehicle]" '; 
		echo ( isset( $this->options[ 'tab_tyre_vehicle' ] ) && !$this->options[ 'tab_tyre_vehicle' ] ) ? '' : 'checked';
		echo '/>';
		echo __('by Vehicle', Plugin::lang );
		echo '</label>';
		echo '&nbsp;&nbsp;&nbsp;';
        echo '<label><input type="checkbox" id="tab_tyre_size" size="80" name="' . PluginOptions::OptionGroup . '[tab_tyre_size]" '; 
		echo ( isset( $this->options[ 'tab_tyre_size' ] ) && !$this->options[ 'tab_tyre_size' ] ) ? '' : 'checked';
		echo '/>';
		echo __('by Size', Plugin::lang );
		echo '</label>';

		echo '<br><br>';
		
		echo __('Show <b>Wheel</b> tabs: ', Plugin::lang ) . '<br>';
        echo '<label><input type="checkbox" id="tab_wheel_vehicle" size="80" name="' . PluginOptions::OptionGroup . '[tab_wheel_vehicle]" '; 
		echo ( isset( $this->options[ 'tab_wheel_vehicle' ] ) && !$this->options[ 'tab_wheel_vehicle' ] ) ? '' : 'checked';
		echo '/>';
		echo __('by Vehicle', Plugin::lang );
		echo '</label>';
		echo '&nbsp;&nbsp;&nbsp;';
        echo '<label><input type="checkbox" id="tab_wheel_size" size="80" name="' . PluginOptions::OptionGroup . '[tab_wheel_size]" '; 
		echo ( isset( $this->options[ 'tab_wheel_size' ] ) && !$this->options[ 'tab_wheel_size' ] ) ? '' : 'checked';
		echo '/>';
		echo __('by Size', Plugin::lang );
		echo '</label>';
		echo '<br><i>You can overwrite tabs by widget local attrs</i>';
    }

	public function tyre_url_callback()
    {
        echo '<input type="text" id="tyre_url" size="80" name="' . PluginOptions::OptionGroup . '[tyre_url]" value="'; 
		echo isset( $this->options[ 'tyre_url' ] ) ? esc_attr( $this->options[ 'tyre_url' ]) : PluginOptions::defaults['tyre_url'];
		echo '" />';
		echo '<br>Default: <i>set to empty ("") to use shop settings: redirect to Woo shop page</i>';
		echo '<br>This is URL for Tyre Search, to Tyre Product Filter';
    }

	public function tyre_fields_callback()
    {
        echo '<input type="text" id="t_field_width" size="7" name="' . PluginOptions::OptionGroup . '[t_field_width]" value="'; 
		echo isset( $this->options[ 't_field_width' ] ) ? esc_attr( $this->options[ 't_field_width' ]) : PluginOptions::defaults['t_field_width'];
		echo '" />';
		echo ' / ';
        echo '<input type="text" id="t_field_profile" size="7" name="' . PluginOptions::OptionGroup . '[t_field_profile]" value="'; 
		echo isset( $this->options[ 't_field_profile' ] ) ? esc_attr( $this->options[ 't_field_profile' ]) : PluginOptions::defaults['t_field_profile'];
		echo '" />';
		echo '&nbsp;&nbsp;&nbsp;&nbsp;';
		echo ' R';
        echo '<input type="text" id="t_field_r" size="7" name="' . PluginOptions::OptionGroup . '[t_field_r]" value="'; 
		echo isset( $this->options[ 't_field_r' ] ) ? esc_attr( $this->options[ 't_field_r' ]) : PluginOptions::defaults['t_field_r'];
		echo '" />';
		echo '<br>Default: <i>[width] / [profile] R[r]</i>';
		echo '<br>This is field names for Search by Size form';
    }

    public function wheel_url_callback()
    {
        echo '<input type="text" id="wheel_url" size="80" name="' . PluginOptions::OptionGroup . '[wheel_url]" value="'; 
		echo isset( $this->options[ 'wheel_url' ] ) ? esc_attr( $this->options[ 'wheel_url' ]) : PluginOptions::defaults['wheel_url'];
		echo '" />';
		echo '<br>Default: <i>set to empty ("") to use shop settings: redirect to Woo shop page</i>';
		echo '<br>This is URL for Wheel Search, to Wheel Product Filter';
    }

	public function wheel_fields_callback()
    {
        echo '<input type="text" id="w_field_width" size="7" name="' . PluginOptions::OptionGroup . '[w_field_width]" value="'; 
		echo isset( $this->options[ 'w_field_width' ] ) ? esc_attr( $this->options[ 'w_field_width' ]) : PluginOptions::defaults['w_field_width'];
		echo '" />';
		echo ' x ';
        echo '<input type="text" id="w_field_r" size="7" name="' . PluginOptions::OptionGroup . '[w_field_r]" value="'; 
		echo isset( $this->options[ 'w_field_r' ] ) ? esc_attr( $this->options[ 'w_field_r' ]) : PluginOptions::defaults['w_field_r'];
		echo '" />';
		echo '&nbsp;&nbsp;&nbsp;&nbsp;';
        echo 'PCD: <input type="text" id="w_field_pcd" size="7" name="' . PluginOptions::OptionGroup . '[w_field_pcd]" value="'; 
		echo isset( $this->options[ 'w_field_pcd' ] ) ? esc_attr( $this->options[ 'w_field_pcd' ]) : PluginOptions::defaults['w_field_pcd'];
		echo '" />';
		echo '&nbsp;&nbsp;&nbsp;&nbsp;';
        echo 'Dia: <input type="text" id="w_field_dia" size="7" name="' . PluginOptions::OptionGroup . '[w_field_dia]" value="'; 
		echo isset( $this->options[ 'w_field_dia' ] ) ? esc_attr( $this->options[ 'w_field_dia' ]) : PluginOptions::defaults['w_field_dia'];
		echo '" />';
		echo '&nbsp;&nbsp;&nbsp;&nbsp;';
		echo 'ET ';
        echo '<input type="text" id="w_field_et" size="7" name="' . PluginOptions::OptionGroup . '[w_field_et]" value="'; 
		echo isset( $this->options[ 'w_field_et' ] ) ? esc_attr( $this->options[ 'w_field_et' ]) : PluginOptions::defaults['w_field_et'];
		echo '" />';
		echo '<br>Default: <i>[width]x[r]</i>';
		echo '<br>This is field names for Search by Size form';
    }

	public function popup_callback()
    {
        echo '<label>';
        echo '<input type="radio" id="popup_default" name="' . PluginOptions::OptionGroup . '[popup_type]" value="default" '; 
		echo ( PluginOptions::value( 'popup_type' ) == 'default' ) ? 'checked' : '';
		echo '/>';
        echo 'Default popup, no plugins';
        echo '</label>';
		echo '<br><i>No need to setup</i>';

		echo '<br><br>';

        echo '<label>';
        echo '<input type="radio" id="popup_pm" name="' . PluginOptions::OptionGroup . '[popup_type]" value="popup-maker" '; 
		echo ( PluginOptions::value( 'popup_type' ) == 'popup-maker' ) ? 'checked' : '';
		echo '/>';
        echo 'Use Popup Maker plugin';
        echo '</label>';
		echo '<br>';
        
        echo 'Popup Maker popup_id: <input type="text" id="popup_id" size="10" name="' . PluginOptions::OptionGroup . '[popup_id]" value="'; 
		echo isset( $this->options[ 'popup_id' ] ) ? esc_attr( $this->options[ 'popup_id' ]) : PluginOptions::defaults['popup_id'];
		echo '" />';
		echo '<br><i>Popup ID you can find in popup\'s CSS class: popmake-ID / ID - is set here</i>';
    }

    public function show_field( $name, $title )
    {
    	$field = [ 	'name' 		=> PluginOptions::OptionGroup . '[' . $name . ']',
			    	'checked' 	=> ( !isset( $this->options[ $name ] ) || !$this->options[ $name ] ) ? '' : 'checked',
			    	'label'		=> __( $title, Plugin::lang ) 
			    	];

        echo '<label><input type="checkbox" name="' . $field['name'] . '" ' . $field['checked'] . '/>' .
				$field['label'] .
			'</label><br>';
    }

    public function theme_callback()
    {
		$theme = isset( $this->options[ 'theme' ] ) ? $this->options[ 'theme' ] : PluginOptions::defaults['theme'];

        echo '<select name="' . PluginOptions::OptionGroup . '[theme]">'; 
        foreach( PluginOptions::themes as $theme_id => $theme_name)
        {
			echo '<option ' . ( ( $theme == $theme_id ) ? 'selected' : '' ) . ' value="' . $theme_id . '">' . $theme_name . '</option>';
		}
		echo '</select>';
		echo '<br>Default: <i>white</i>';
		echo "<br>This is Theme for finder.";

		echo "<br><br>";

    	$this->show_field( 'show_r', 	__( 'Show R for diameters (R15)', Plugin::lang ) );
    }

	public function custom_css_callback()
    {
        echo '<textarea id="custom_css" cols="80" rows="5" name="' . PluginOptions::OptionGroup . '[custom_css]">'; 
		echo isset( $this->options[ 'custom_css' ] ) ? esc_attr( $this->options[ 'custom_css' ]) : PluginOptions::defaults['custom_css'];
		echo '</textarea>';
		echo '<br>Default: <i>CSS for rewrite: just write CSS here</i>';
		echo '<br>This is developer field, inlined in tag:head, try to use another methods. If you use CSS here, plugin css will off.';
    }


    // init

	public function admin_menu() 
	{
		if ( class_exists('TyresAddict\Finder\FeatureProMenu') )
			add_submenu_page( 'tyres-wheels', 
							__( 'Tyre Finder Demo options', Plugin::lang ), 
							__( 'Tyre Finder <span style="opacity:0.5;">Demo</span>', Plugin::lang ), 
							'manage_options', 
							Plugin::name . '-menu', 
							[ $this, 'page'] );  

		add_options_page( 	__('Tyre Finder Demo Options', Plugin::lang), 
								__('Tyre Finder <span style="opacity:0.5;">Demo</span>', Plugin::lang), 
								'manage_options', Plugin::name, [ $this, 'page' ]);
	}

	public function register() 
	{
		add_action( 'admin_menu', [ $this, 'admin_menu' ] );	
        add_action( 'admin_init', [ $this, 'register_page' ] );
	}

}




