<?php

/**
 * Fired during plugin de/activation
 *
 * @since      1.0.0
 * @package    TyresAddict
 * @subpackage TyresAddict/Finder/includes
 * @author     TyresAddict
 * @link       http://b2b.tyresaddict.com
 */

namespace TyresAddict\Finder;


/**
 * Fired during plugin de/activation.
 *
 */
class PluginInstaller
{

	public static function activate() 
	{
		PluginInstaller::db_create();
	}

	public static function deactivate() 
	{
		delete_option( Plugin::prefix . 'deferred-admin-notices' );
		delete_option( PluginOptions::OptionGroup );
		PluginInstaller::db_drop();
	}

	public static function check_environment()
	{
		// Check Woo

		if ( !in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
			Woo::admin_notice( __( Plugin::title . ' need WooCommerce plugin for working, please, install it' ) );
			return false;
		}

		return true;
	}


	public static function db_drop()
	{
	    global $wpdb;

		$sql = "DROP TABLE IF EXISTS " . DB::vehicle_db();
		$wpdb->query( $sql );
	}

	public static function db_create()
	{
	    global $wpdb;

	    if( $wpdb->get_var("SHOW TABLES LIKE '" . DB::vehicle_db() . "'") != DB::vehicle_db()) 
    	{
			if ( !function_exists( 'dbDelta' ) ) {
				require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
			}
		
			$sql = PluginInstaller::db_create_sql();

    	    dbDelta( $sql );
	    }
	}

	public static function db_create_sql()
	{
		$sql = "CREATE TABLE " . DB::vehicle_db() . " (
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`vendor` varchar(255) NOT NULL,
				`model_seria` varchar(255) NOT NULL,
				`car` varchar(255) NOT NULL,
				`year` varchar(255) NOT NULL,
				`modification` varchar(255) NOT NULL,
				`param_pcd` varchar(32) NOT NULL,
				`param_dia` varchar(8) NOT NULL,
				`param_nut` varchar(32) NOT NULL,
				`param_bolt` varchar(32) NOT NULL,
				`tyres_factory` text NOT NULL,
				`tyres_replace` text NOT NULL,
				`tyres_tuning` text NOT NULL,
				`wheels_factory` text NOT NULL,
				`wheels_replace` text NOT NULL,
				`wheels_tuning` text NOT NULL,
				PRIMARY KEY (`id`),
				KEY `vendor` (`vendor`),
				KEY `car` (`car`),
				KEY `year` (`year`),
				KEY `modification` (`modification`)
  				) ENGINE=MyISAM  DEFAULT CHARSET=utf8";

		return $sql;
	}

}
