<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @since      1.0.0
 * @package    TyresAddict
 * @subpackage TyresAddict/Finder/includes
 * @author     TyresAddict
 * @link       http://b2b.tyresaddict.com
 */


namespace TyresAddict\Finder;


// The public-facing functionality of the plugin.

class PluginPublic 
{
	private $template = null;

	public function __construct() 
	{
		$this->template = new Template();
	}

	// Ajax calls

	public function ajax_controller() 
	{
		$data = [];

		$method = isset( $_GET['method'] ) ? $_GET['method'] : false;

		if ( !$method )
			wp_die();

		$methods = [ 'vehicledb_models', 'vehicledb_years', 'vehicledb_mods', 'vehicledb_trim', 'vehicledb_trim_wheels' ];

		if ( !in_array( $method, $methods ) )
			wp_die();

		$ajax_method = 'ajax_' . $method;
		$this->$ajax_method();

		wp_die();
		
	}

	public function ajax_vehicledb_models() 
	{
		$make  	= isset( $_GET['make'] ) ? $_GET['make'] : false;

		$models = DB::models( $make );
		echo json_encode( [ 'result' => true, 'models' => $models ] );
	}

	public function ajax_vehicledb_years() 
	{
		$make  	= isset( $_GET['make'] ) ? $_GET['make'] : false;
		$model  = isset( $_GET['model'] ) ? $_GET['model'] : false;

		$years = DB::years( $make, $model );
		echo json_encode( [ 'result' => true, 'years' => $years ] );
	}

	public function ajax_vehicledb_mods() 
	{
		$make  	= isset( $_GET['make'] ) ? $_GET['make'] : false;
		$model  = isset( $_GET['model'] ) ? $_GET['model'] : false;
		$year  	= isset( $_GET['year'] ) ? $_GET['year'] : false;

		$mods = DB::mods( $make, $model, $year );
		echo json_encode( [ 'result' => true, 'mods' => $mods ] );
	}

	public function ajax_vehicledb_trim() 
	{
		$make  	= isset( $_GET['make'] ) ? $_GET['make'] : false;
		$model  = isset( $_GET['model'] ) ? $_GET['model'] : false;
		$year  	= isset( $_GET['year'] ) ? $_GET['year'] : false;
		$mod  	= isset( $_GET['mod'] ) ? $_GET['mod'] : false;

		$trim = DB::trim( $make, $model, $year, $mod, PluginOptions::value('tyre_url') );
		echo json_encode( [ 'result' 	=> true, 
							'car'		=> $make . ' ' . $model . ' ' . $year . ' ' . $mod,
							'html' 		=> 	$this->template->fetch('finder-trims', [ 'type' => 'factory', 	'trims' => $trim->tyres_factory, 	'txtdomain' => Plugin::name ] ).
											$this->template->fetch('finder-trims', [ 'type' => 'replace', 	'trims' => $trim->tyres_replace, 	'txtdomain' => Plugin::name ] ).
											$this->template->fetch('finder-trims', [ 'type' => 'tuning', 	'trims' => $trim->tyres_tuning, 	'txtdomain' => Plugin::name ] ), 
							'trim' 		=> $trim ] );
	}

	public function ajax_vehicledb_trim_wheels() 
	{
		$make  	= isset( $_GET['make'] ) ? $_GET['make'] : false;
		$model  = isset( $_GET['model'] ) ? $_GET['model'] : false;
		$year  	= isset( $_GET['year'] ) ? $_GET['year'] : false;
		$mod  	= isset( $_GET['mod'] ) ? $_GET['mod'] : false;

		$trim = DB::trim( $make, $model, $year, $mod, PluginOptions::value('wheel_url') );

		echo json_encode( [ 'result' 	=> true, 
							'car'		=> $make . ' ' . $model . ' ' . $year . ' ' . $mod,
							'html' 		=> 	$this->template->fetch('finder-trims-wheel-common', [ 'params' => $trim ] ).
											$this->template->fetch('finder-trims-wheel', [ 'type' => 'factory', 'trims' => $trim->wheels_factory, 	'params' => $trim, 	'txtdomain' => Plugin::name ] ).
											$this->template->fetch('finder-trims-wheel', [ 'type' => 'replace', 'trims' => $trim->wheels_replace, 	'params' => $trim, 	'txtdomain' => Plugin::name ] ).
											$this->template->fetch('finder-trims-wheel', [ 'type' => 'tuning', 	'trims' => $trim->wheels_tuning, 	'params' => $trim, 	'txtdomain' => Plugin::name ] ), 
							'trim' 		=> $trim ] );
	}

	// Enqueue styles

	public function enqueue_inline_styles_css()
	{
		if ( is_single() || is_page() ) {
			echo '<style type="text/css"><!-- TyresAddict Woo Finder CSS -->' . PluginOptions::value('custom_css') . '</style>';
		}
	}

	public function enqueue_styles() 
	{                                   
		if ( trim( PluginOptions::value('custom_css') ) != '' )
			add_action('wp_head', [ $this, 'enqueue_inline_styles_css' ], 99 );
		else
		{
			if ( trim( PluginOptions::value('theme') ) == 'all' )
			{
				foreach( PluginOptions::themes as $theme => $theme_name )
				{
					if ( $theme != 'all' )
						wp_enqueue_style( Plugin::name . '-' . $theme, plugins_url() . '/' . Plugin::name . '/public/css/finder-' . $theme . '.css', [], Plugin::version, 'all' );
				}
			}
			else
				wp_enqueue_style( Plugin::name, plugins_url() . '/' . Plugin::name . '/public/css/finder-' . PluginOptions::value('theme') . '.css', [], Plugin::version, 'all' );
		}

		if ( PluginOptions::value('popup_type') == 'default' )
			wp_enqueue_style( Plugin::name.'-izim-css', 'https://cdnjs.cloudflare.com/ajax/libs/izimodal/1.5.1/css/iziModal.min.css', [], Plugin::version, 'all' );
	}

	// Register the JavaScript for the public-facing side of the site.

	public function enqueue_scripts() 
	{                          
		wp_register_script( Plugin::name, plugins_url() . '/' . Plugin::name . '/public/js/finder-public.js', [ 'jquery' ], Plugin::version, false );

		wp_enqueue_script( Plugin::name );
		wp_localize_script( Plugin::name, "tyresaddict_woo_finder", [
			'ajax_url'		=> admin_url( 'admin-ajax.php' ),
			'tyre_url'		=> PluginOptions::value('tyre_url'),
			'wheel_url'		=> PluginOptions::value('wheel_url'),
			'popup_type'	=> PluginOptions::value('popup_type'),
			'popup_id'		=> PluginOptions::value('popup_id')
		] );

		if ( PluginOptions::value('popup_type') == 'default' )
			wp_enqueue_script( Plugin::name.'-izim', 'https://cdnjs.cloudflare.com/ajax/libs/izimodal/1.5.1/js/iziModal.min.js', [ 'jquery' ], Plugin::version, false );
	}

}

