<?php

/**
 * Simple Template
 *
 * @since      1.0.0
 * @package    TyresAddict
 * @subpackage TyresAddict/Finder/includes
 * @author     TyresAddict
 * @link       http://b2b.tyresaddict.com
 */

namespace TyresAddict\Finder;


// Template Class

class Template
{
	protected $template_path = '';

	// Setup template path

	public function __construct( $template_path = '' ) 
	{
		if ( $template_path ) {
			$this->template_path = Plugin::path() . $template_path . '/';
		} else {
			$this->template_path = Plugin::path() . 'templates/';
		}
	}

	public function display( $template, $theme = '', array $data = [] ) 
	{
		if ( $theme != '' )
			$template = $template . '-' . $theme;

		echo $this->fetch( $template, $data );
	}

	// Fetch a template, returns string
	// throws RuntimeException if template does not exist

	public function fetch( $template, array $data = [] ) 
	{
		// Look in templates folder.
		if ( ! is_file( $this->template_path ) ) {
			$file = $this->template_path . $template . '.php';
			if ( ! is_file( $file ) ) {
				throw new \RuntimeException( "View cannot render `$template` because the template does not exist" );
			}
		}

		// pre-compile
	
		$file = $this->compile( $file );

		// add textdomain

		$data['t'] = Plugin::lang;

		ob_start();
		$this->sandbox( $file, $data );
		$output = ob_get_clean();

		return $output;
	}

	// compile

	protected function compile( $template ) 
	{
		$compiled_template = $template . '.compiled.php';

		if ( !Woo::dev() )
			return $compiled_template;
		
		$content = file_get_contents( $template );

		$content = $this->compileStatements( $content );
		$content = $this->compileTags( $content );

		file_put_contents( $compiled_template, $content );
		return $compiled_template;
	}

	// from blade
	protected function compileStatements($value)
    {
        return preg_replace_callback(
            '/\B@(@?\w+(?:::\w+)?)([ \t]*)(\( ( (?>[^()]+) | (?3) )* \))?/x', function ($match) {
            	if ($match[1] == 'foreach')			return '<?php foreach' . $match[3] . ' : ?>';
            	if ($match[1] == 'endforeach')		return '<?php endforeach ?>';

            	if ($match[1] == 'if')			return '<?php if' . $match[3] . ' : ?>';
            	if ($match[1] == 'else')		return '<?php else: ?>';
            	if ($match[1] == 'endif')		return '<?php endif ?>';
            }, $value
        );
    }

	protected function compileTags($value)
    {
        return preg_replace_callback(
            '/{{\s+(.*?)\s+}}/x', function ($match) {
            	return '<?= ' . $match[1] . ' ?>';
            }, $value
        );
    }

	// sandbox for template variables

	protected function sandbox( $template, array $data ) 
	{
		extract( $data );
		include $template;
	}

}


